@@ -24,6 +24,8 @@
 #'   use the multivariate normal-theory approach.
 #'   If `type = "adf"`,
 #'   use the asymptotic distribution-free approach.
+#' @param alpha Numeric vector.
+#'   Significance level \eqn{\alpha}.
 #'
 #' @references
 #' Jones, J. A., & Waller, N. G. (2015).
@@ -53,11 +55,13 @@
 #' coef(std)
 #' vcov(std)
 #' confint(std, level = 0.95)
-#' @export
+#'
 #' @family Beta Delta Functions
 #' @keywords betaDelta std
+#' @export
 BetaDelta <- function(object,
-                      type = "mvn") {
+                      type = "mvn",
+                      alpha = c(0.05, 0.01, 0.001)) {
   stopifnot(
     type %in% c(
       "mvn",
@@ -65,43 +69,24 @@ BetaDelta <- function(object,
     )
   )
   lm_process <- .ProcessLM(object)
-  gamma <- .Gamma(
-    object = lm_process,
+  std <- .BetaDelta(
+    lm_process = lm_process,
     type = type
   )
-  acov <- .ACovDelta(
-    jcap = .JacobianBetastarWRTVechSigma(
-      beta = lm_process$beta,
-      sigmay = sqrt(lm_process$sigmacap[1, 1]),
-      sigmax = sqrt(diag(lm_process$sigmacap)[-1]),
-      invsigmacapx = chol2inv(
-        chol(
-          lm_process$sigmacap[
-            2:lm_process$k,
-            2:lm_process$k,
-            drop = FALSE
-          ]
-        )
-      ),
-      p = lm_process$p,
-      k = lm_process$k
-    ),
-    acov = gamma
-  )
-  colnames(acov) <- rownames(acov) <- lm_process$xnames
-  vcov <- (1 / lm_process$n) * acov
   out <- list(
     call = match.call(),
     args = list(
       object = object,
-      type = type
+      type = type,
+      alpha = alpha
     ),
     lm_process = lm_process,
-    gamma = gamma,
-    acov = acov,
-    vcov = vcov,
+    gamma = std$gamma,
+    acov = std$acov,
+    vcov = std$vcov,
     est = lm_process$betastar
   )
+  attributes(out)$mi <- FALSE
   class(out) <- c(
     "betadelta",
     class(out)
